==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebMRLColumnSizeInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLColumnSizeInfoDescription } from "./WebMRLColumnSizeInfoDescription";
/**
 * @hidden
 */
export let WebMRLColumnSizeInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMRLColumnSizeInfoDescriptionMetadata extends Base {
        static b(a) {
            if (WebMRLColumnSizeInfoDescriptionMetadata.a == null) {
                WebMRLColumnSizeInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMRLColumnSizeInfoDescriptionMetadata.c(WebMRLColumnSizeInfoDescriptionMetadata.a);
            }
            if (a.j(WebMRLColumnSizeInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:MRLColumnSizeInfo");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebMRLColumnSizeInfoDescriptionMetadata.b(a);
            a.aa("WebMRLColumnSizeInfo", () => new WebMRLColumnSizeInfoDescription());
            a.z("WebMRLColumnSizeInfo", WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
    }
    WebMRLColumnSizeInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMRLColumnSizeInfoDescriptionMetadata, 'WebMRLColumnSizeInfoDescriptionMetadata');
    WebMRLColumnSizeInfoDescriptionMetadata.a = null;
    return WebMRLColumnSizeInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebMRLColumnSizeInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebMRLColumnSizeInfoDescription } from "./WebMRLColumnSizeInfoDescription";
/**
 * @hidden
 */
export let WebMRLColumnSizeInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebMRLColumnSizeInfoDescriptionMetadata extends Base {
        static b(a) {
            if (WebMRLColumnSizeInfoDescriptionMetadata.a == null) {
                WebMRLColumnSizeInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebMRLColumnSizeInfoDescriptionMetadata.c(WebMRLColumnSizeInfoDescriptionMetadata.a);
            }
            if (a.k(WebMRLColumnSizeInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:MRLColumnSizeInfo");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebMRLColumnSizeInfoDescriptionMetadata.b(a);
            a.ac("WebMRLColumnSizeInfo", () => new WebMRLColumnSizeInfoDescription());
            a.ab("WebMRLColumnSizeInfo", WebMRLColumnSizeInfoDescriptionMetadata.a);
        }
    }
    WebMRLColumnSizeInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(WebMRLColumnSizeInfoDescriptionMetadata, 'WebMRLColumnSizeInfoDescriptionMetadata');
    WebMRLColumnSizeInfoDescriptionMetadata.a = null;
    return WebMRLColumnSizeInfoDescriptionMetadata;
})();
